@@ -1,5 +1,5 @@
 #choose separator and decimal type
-NCAcsv<-function(BANOVA=FALSE)
+NCAcsv<-function(replicated=FALSE)
 {
 cat("\n")
 file.menu <- c("separator = comma (,) &  decimal = point (.)",
@@ -19,13 +19,23 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=",",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+           if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+           }
      }
      
  else {
@@ -34,13 +44,23 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=",")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+           if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+           }
           }
         
  else {
@@ -49,13 +69,23 @@ if (pick == 1){
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+           if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+           }
           }
 else {
   if (pick == 4){
@@ -63,13 +93,23 @@ else {
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=",")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+           if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+           }
           } 
 else {
   if (pick == 5){
@@ -77,13 +117,23 @@ else {
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+           if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+           }
           }                   
 else {
   if (pick == 6){
@@ -91,13 +141,23 @@ else {
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames,  sep="\t",dec=",")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+           if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+           }
           }                             
 else {
   if (pick == 7){
@@ -105,13 +165,23 @@ else {
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+           if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+           }
           }                   
 else {
   if (pick == 8){
@@ -119,13 +189,23 @@ else {
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=",")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+          if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+            }
            }  
 else {
   if (pick == 9){
@@ -133,18 +213,33 @@ else {
         description_import()
         TotalSingledata.file <-readline()
         TotalSingledata.file<-paste(TotalSingledata.file,".csv",sep="")
+        if(replicated){
+        cnames<-c("subj", "seq", "prd", "drug","time", "conc")
+        }
+         else{
         cnames<-c("subj", "seq","prd", "time", "conc")
+        }
         TotalSingledata<-read.csv(TotalSingledata.file,header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=".")
         TotalSingledata<-edit(TotalSingledata)
         TotalSingledata<-na.omit(TotalSingledata)
         cat("\n\n")
         show(TotalSingledata)
+          if(replicated){
+           return(RepNCAanalyze(TotalSingledata))
+           }
+         else{
            return(NCAanalyze(TotalSingledata))
+            }
            }              
  else {
   if (pick == 10){
-      return (NCAmenu())
-                }
+      if(replicated){
+           return(Repmenu())
+           }
+         else{
+           return (NCAmenu())
+            }
+           }
           }
          }
         }
