@@ -1,19 +1,48 @@
 ##export with pdf file
 library(sciplot)
-NCAplot<-function(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
+NCAplot<-function(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,
+                  replicated=FALSE)
 {
 options(warn=-1)
-d.split<-split(Totalplot,list(Totalplot$drug))
-s.split<-split(Totalplot,list(Totalplot$subj))
 
-LR<-data.frame(subj=Totalplot$subj,  seq=Totalplot$seq, prd=Totalplot$prd, drug=Totalplot$drug,
+if(replicated){
+     Totalplot<-Totalplot[ do.call(order, Totalplot) ,]
+     s.split<-split(Totalplot,list(Totalplot$subj))
+          
+     LR<-data.frame(subj=Totalplot$subj,  seq=Totalplot$seq, prd=Totalplot$prd, drug=Totalplot$drug,
+                    time=Totalplot$time,  conc=Totalplot$conc, code=Totalplot$code)
+     LR$conc[LR$conc == 0] <- NA
+     LR <- na.omit(LR)
+     Ls.split<-split(LR, list(LR$subj))
+
+     
+     Totals.split<-split(TotalData, list(TotalData$drug))
+     
+     Fdata<-split(TotalData, list(TotalData$drug))
+     RefData<-Fdata[[1]]
+     TestData<-Fdata[[2]]
+      SeqLeg<-split(RefData, list(RefData$seq))
+      SeqLeg1 <- reshape(SeqLeg[[1]], idvar=c("subj", "drug","seq"), timevar =
+      "prd",direction = "wide")
+      SeqLeg2 <- reshape(SeqLeg[[2]], idvar=c("subj", "drug","seq"), timevar =
+      "prd",direction = "wide")  
+      L1<-length(SeqLeg1$subj)
+      L2<-length(SeqLeg2$subj)
+     
+     prdcount<-length(levels(TotalData$prd))
+       }
+     else{
+     s.split<-split(Totalplot,list(Totalplot$subj))
+
+     LR<-data.frame(subj=Totalplot$subj,  seq=Totalplot$seq, prd=Totalplot$prd, drug=Totalplot$drug,
                time=Totalplot$time,  conc=Totalplot$conc)
-LR$conc[LR$conc == 0] <- NA
-LR <- na.omit(LR)
-Ls.split<-split(LR, list(LR$subj))
+     LR$conc[LR$conc == 0] <- NA
+     LR <- na.omit(LR)
+     Ls.split<-split(LR, list(LR$subj))
 
-Totals.split<-split(TotalData, list(TotalData$drug))
-L<-length(Totals.split[[1]]$subj)
+     Totals.split<-split(TotalData, list(TotalData$drug))
+     L<-length(Totals.split[[1]]$subj)
+    }
 
 
 pdf("NCAplots.pdf")
@@ -23,46 +52,75 @@ description_plot()
 
 #1.#################################individual subject for test vs ref (Cp vs time)
 
-s.split<-split(Totalplot,list(Totalplot$subj))
+
 for(i in seq_along(s.split)){
 main<-paste(c("Subject#", s.split[[i]]$subj[1]),collapse=" ")
-lineplot.CI(s.split[[i]]$time, s.split[[i]]$conc, group = s.split[[i]]$drug, cex = 1,
+  if(replicated){
+     lineplot.CI(s.split[[i]]$time, s.split[[i]]$conc, group = s.split[[i]]$code, cex = 1,
+                 xlab=xaxis, ylab=yaxis,cex.lab = 1, x.leg = 100000, bty="l",main=main,
+                 font.lab=2,cex.axis=1,cex.main=1,las=1,x.cont=TRUE,xaxt="n")  
+      }
+      else{
+        lineplot.CI(s.split[[i]]$time, s.split[[i]]$conc, group = s.split[[i]]$drug, cex = 1,
             xlab=xaxis, ylab=yaxis,cex.lab = 1, x.leg = 100000, bty="l",main=main,
             font.lab=2,cex.axis=1,cex.main=1,las=1,x.cont=TRUE,xaxt="n"
              )
+ }            
    axis(1,at=c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100,
                105,110,115,120,125,130,135,140,145,150,155,160,165,170,175,180,185,190,195,200),las=0)
    axis(1,at=0:100,tcl=-.2, labels=FALSE)
-   axis(2,yaxp=c(0, 4000, 40),las=1,tcl=-.2, labels=FALSE)
+   axis(2,yaxp=c(0, 10000, 100),las=1,tcl=-.2, labels=FALSE)
+if(replicated){
+  prdcount(i,s.split, prdcount)
+ }
+else{
 temp <- legend("topright",legend = c("Test", "Ref"),
                text.width = strwidth("1,000,000"),
                lty = 1:2, xjust = 1, yjust = 1)
-  
  }
+} 
 
-#2.#####################################individual subject for test vs ref (Cp vs time)
+#2.#####################################individual subject for test vs ref (lnCp vs time)
 
 for(i in seq_along(Ls.split)){
 main<-paste(c("Subject#", Ls.split[[i]]$subj[1]),collapse=" ")
-lineplot.CI(Ls.split[[i]]$time, Ls.split[[i]]$conc, log="y", group = Ls.split[[i]]$drug, cex = 1,
-     xlab = "Time", ylab = "Conc. (in log scale)",cex.lab = 1, x.leg = 100000, bty="l",main=main,
-     font.lab=2,cex.axis=1,cex.main=1,las=1,x.cont=TRUE,xaxt="n"
+   if(replicated){
+      lineplot.CI(Ls.split[[i]]$time, Ls.split[[i]]$conc, log="y", group = Ls.split[[i]]$code, cex = 1,
+                  xlab = "Time", ylab = "Conc. (in log scale)",cex.lab = 1, x.leg = 100000, bty="l",main=main,
+                  font.lab=2,cex.axis=1,cex.main=1,las=1,x.cont=TRUE,xaxt="n")
+    }
+    else{
+      lineplot.CI(Ls.split[[i]]$time, Ls.split[[i]]$conc, log="y", group = Ls.split[[i]]$drug, cex = 1,
+          xlab = "Time", ylab = "Conc. (in log scale)",cex.lab = 1, x.leg = 100000, bty="l",main=main,
+          font.lab=2,cex.axis=1,cex.main=1,las=1,x.cont=TRUE,xaxt="n"
              )
+      } 
    axis(1,at=c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100,
               105,110,115,120,125,130,135,140,145,150,155,160,165,170,175,180,185,190,195,200),las=0)
    axis(1,at=0:100,tcl=-.2, labels=FALSE)
+if(replicated){
+  prdcount(i,s.split, prdcount)
+ }
+else{
 temp <- legend("topright",legend = c("Test", "Ref"),
                text.width = strwidth("1,000,000"),
                lty = 1:2, xjust = 1, yjust = 1)
-  
+  }
  }
 
 #3. ###############################show all subjects in one plot at the same time for test
-
+if(replicated){
+lineplot.CI(SingleTdata$time, SingleTdata$conc, group = SingleTdata$code, type="l",
+           xlab=xaxis, ylab=yaxis,ylim=c(0,max(Totalplot$conc)),cex.lab = 1,x.leg =1000000, bty="l", lty=1,las=1,
+            font.lab=2,cex.axis=1,cex.main=1,x.cont=TRUE,xaxt="n" 
+             )
+}
+else{
 lineplot.CI(SingleTdata$time, SingleTdata$conc, group = SingleTdata$subj, type="l",
            xlab=xaxis, ylab=yaxis,ylim=c(0,max(Totalplot$conc)),cex.lab = 1,x.leg =1000000, bty="l", lty=1,las=1,
             font.lab=2,cex.axis=1,cex.main=1,x.cont=TRUE,xaxt="n" 
              )
+    }         
             axis(1,at=c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100,
                        105,110,115,120,125,130,135,140,145,150,155,160,165,170,175,180,185,190,195,200),las=0)
             axis(1,at=0:100,tcl=-.2, labels=FALSE)
@@ -71,11 +129,18 @@ lineplot.CI(SingleTdata$time, SingleTdata$conc, group = SingleTdata$subj, type="
  
 
 #4. ###############################show all subjects in one plot at the same time for ref
-
+if(replicated){
+lineplot.CI(SingleRdata$time, SingleRdata$conc, group = SingleRdata$code, type="l",
+            xlab=xaxis, ylab=yaxis,ylim=c(0,max(Totalplot$conc)),cex.lab = 1,x.leg =100000, bty="l",lty=1,las=1,
+            font.lab=2,cex.axis=1,cex.main=1,las=1,x.cont=TRUE,xaxt="n" 
+             )
+}
+else{
 lineplot.CI(SingleRdata$time, SingleRdata$conc, group = SingleRdata$subj, type="l",
             xlab=xaxis, ylab=yaxis,ylim=c(0,max(Totalplot$conc)),cex.lab = 1,x.leg =100000, bty="l",lty=1,las=1,
             font.lab=2,cex.axis=1,cex.main=1,las=1,x.cont=TRUE,xaxt="n" 
              )
+}             
             axis(1,at=c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100,
                         105,110,115,120,125,130,135,140,145,150,155,160,165,170,175,180,185,190,195,200),las=0)
             axis(1,at=0:100,tcl=-.2, labels=FALSE)
@@ -85,7 +150,12 @@ lineplot.CI(SingleRdata$time, SingleRdata$conc, group = SingleRdata$subj, type="
 
 #5. ##########################mean+*-sd plot for test and ref drug
 
+if(replicated){
+main<-paste(c("Observed mean drug plasma concentration, N=",L1+L2),collapse=" ")
+}
+else{
 main<-paste(c("Observed mean drug plasma concentration, N=",L),collapse=" ")
+}
 lineplot.CI(Totalplot$time, Totalplot$conc, group = Totalplot$drug, cex = 1, main=main,
             xlab=xaxis, ylab=yaxis,cex.lab = 1,x.leg =100000, bty="l", las=1,
             font.lab=2,cex.axis=1,cex.main=1,x.cont=TRUE,xaxt="n" ,err.lty=1,err.width=0.05
@@ -93,7 +163,7 @@ lineplot.CI(Totalplot$time, Totalplot$conc, group = Totalplot$drug, cex = 1, mai
             axis(1,at=c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100,
                        105,110,115,120,125,130,135,140,145,150,155,160,165,170,175,180,185,190,195,200),las=0)
             axis(1,at=0:100,tcl=-.2, labels=FALSE)
-            axis(2,yaxp=c(0, 4000, 40),las=1,tcl=-.2, labels=FALSE)
+            axis(2,yaxp=c(0, 10000, 100),las=1,tcl=-.2, labels=FALSE)
 temp <- legend("topright",legend = c("Test", "Ref."),
                text.width = strwidth("1,000,000"),
                lty = 1:2, xjust = 1, yjust = 1)
