@@ -1,5 +1,5 @@
 ##save the NCA results 
-NCAsave<-function(TotalData){
+NCAsave<-function(TotalData, replicated=FALSE){
 
   cat("\n\n")
      cat("\nEnter the file name (without file extention):\n")
@@ -40,7 +40,12 @@ NCAsave<-function(TotalData){
                 else{
                  save(TotalData,file=Totalname)
                   }
+               if(replicated){
+              RepMIXmenu(TotalData)
+               }
+              else{
               BANOVAmenu(TotalData)
+              }
 }
 
  
\ No newline at end of file
