@@ -1,4 +1,4 @@
 NCAselectdemo.BANOVA<-function(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis){
 NCAselect(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis,
-         Demo=TRUE, BANOVA=TRUE)
+         Demo=TRUE, BANOVA=TRUE, replicated=FALSE, MIX=FALSE)
 }
\ No newline at end of file
