@@ -6,14 +6,14 @@ cat("\n")
 cat("***********************************************************************\n")
 cat("                                                                     \n")
 cat("                                  bear                               \n")
-cat("                                v 2.1.0                              \n")   
+cat("                                v 2.2.0                              \n")   
 cat("                    http://pkpd.kmu.edu.tw/bear                      \n")
 cat("                                                                     \n")
 cat(" This package is designed to analyze average bioequivalence (ABE)    \n")
 cat(" (NCA -> ANOVA) or bioavailability (NCA only) data, with study       \n")
 cat(" design of a standard RT/TR 2-treatment, 2-sequence, and 2-period,   \n")
-cat(" crossover design.  Currently, it should NOT be used to analyze      \n")
-cat(" replicated ABE study.                                               \n")
+cat(" crossover design, as well as replicate ABE study including          \n")
+cat(" 2-treatment, 2-sequence, and more than 2 periods (i.e., 2x2x3/2x2x4). \n")
 cat("                                                                     \n")
 cat("                   Please type 'go()' to get started.                \n")
 cat("                                                                     \n")
